@@ -69,7 +69,7 @@ this module usually compares favourably in terms of speed, too.
 =item * simple to use
 
 This module has both a simple functional interface as well as an object
-oriented interface interface.
+oriented interface.
 
 =item * reasonably versatile output formats
 
@@ -94,7 +94,7 @@ or        L<https://rt.cpan.org/Public/Dist/Display.html?Queue=Cpanel-JSON-XS>
 
 B<Changes to JSON::XS>
 
-- public maintainance and bugtracker.
+- public maintenance and bugtracker.
 
 - added C<binary> extension, non-JSON and non JSON parsable, allows
   C<\xNN> and C<\NNN> sequences.
@@ -109,11 +109,22 @@ B<Changes to JSON::XS>
 
 - extended testsuite
 
+- interop for true/false overloading. JSON::XS representations are
+  accepted and JSON::XS accepts Cpanel::JSON::XS booleans [#13]
+
+- additional fixes for:
+
+  - [cpan #88061] AIX atof without USE_LONG_DOUBLE
+
+  - #10 unshare_hek crash
+
+  - #7 avoid re-blessing where possible (e.g. SvREADONLY restricted hashes)
+
 =cut
 
 package Cpanel::JSON::XS;
 
-our $VERSION = '2.3402';
+our $VERSION = '2.3404';
 our @ISA = qw(Exporter);
 
 our @EXPORT = qw(encode_json decode_json to_json from_json);
@@ -807,7 +818,7 @@ If the method is called in scalar context, then it will try to extract
 exactly I<one> JSON object. If that is successful, it will return this
 object, otherwise it will return C<undef>. If there is a parse error,
 this method will croak just as C<decode> would do (one can then use
-C<incr_skip> to skip the errornous part). This is the most common way of
+C<incr_skip> to skip the erroneous part). This is the most common way of
 using the method.
 
 And finally, in list context, it will try to extract as many objects
@@ -848,7 +859,7 @@ state is left unchanged, to skip the text parsed so far and to reset the
 parse state.
 
 The difference to C<incr_reset> is that only text until the parse error
-occured is removed.
+occurred is removed.
 
 =item $json->incr_reset
 
@@ -1056,24 +1067,24 @@ it as an integer value. If that fails, it will try to represent it as
 a numeric (floating point) value if that is possible without loss of
 precision. Otherwise it will preserve the number as a string value (in
 which case you lose roundtripping ability, as the JSON number will be
-re-encoded toa JSON string).
+re-encoded to a JSON string).
 
 Numbers containing a fractional or exponential part will always be
 represented as numeric (floating point) values, possibly at a loss of
 precision (in which case you might lose perfect roundtripping ability, but
 the JSON number will still be re-encoded as a JSON number).
 
-Note that precision is not accuracy - binary floating point values cannot
-represent most decimal fractions exactly, and when converting from and to
-floating point, Cpanel::JSON::XS only guarantees precision up to but not including
-the leats significant bit.
+Note that precision is not accuracy - binary floating point values
+cannot represent most decimal fractions exactly, and when converting
+from and to floating point, Cpanel::JSON::XS only guarantees precision
+up to but not including the least significant bit.
 
 =item true, false
 
 These JSON atoms become C<JSON::XS::true> and C<JSON::XS::false>,
 respectively. They are overloaded to act almost exactly like the numbers
 C<1> and C<0>. You can check whether a scalar is a JSON boolean by using
-the C<JSON::XS::is_bool> function.
+the C<Cpanel::JSON::XS::is_bool> function.
 
 =item null
 
@@ -1207,7 +1218,7 @@ the same time, which can be confusing.
 When C<utf8> is disabled (the default), then C<encode>/C<decode> generate
 and expect Unicode strings, that is, characters with high ordinal Unicode
 values (> 255) will be encoded as such characters, and likewise such
-characters are decoded as-is, no canges to them will be done, except
+characters are decoded as-is, no changes to them will be done, except
 "(re-)interpreting" them as Unicode codepoints or Unicode characters,
 respectively (to Perl, these are the same thing in strings unless you do
 funny/weird/dumb stuff).
@@ -1336,7 +1347,7 @@ output for these property strings, e.g.:
    $json =~ s/"__proto__"\s*:/"__proto__renamed":/g;
 
 This works because C<__proto__> is not valid outside of strings, so every
-occurence of C<"__proto__"\s*:> must be a string used as property name.
+occurrence of C<"__proto__"\s*:> must be a string used as property name.
 
 If you know of other incompatibilities, please let me know.
 
@@ -1542,22 +1553,28 @@ JSON::XS as our serializer of choice.
 
 L<https://rt.cpan.org/Public/Dist/Display.html?Queue=Cpanel-JSON-XS>
 
+=head1 LICENSE
+
+This module is available under the same licences as perl, the Artistic
+license and the GPL.
+
 =cut
 
-our $true  = do { bless \(my $dummy = 1), "Cpanel::JSON::XS::Boolean" };
-our $false = do { bless \(my $dummy = 0), "Cpanel::JSON::XS::Boolean" };
+our $true  = do { bless \(my $dummy = 1), "JSON::XS::Boolean" };
+our $false = do { bless \(my $dummy = 0), "JSON::XS::Boolean" };
 
 sub true()  { $true  }
 sub false() { $false }
 
 sub is_bool($) {
-   UNIVERSAL::isa $_[0], "Cpanel::JSON::XS::Boolean"
-#      or UNIVERSAL::isa $_[0], "JSON::Literal"
+  UNIVERSAL::isa $_[0], "JSON::XS::Boolean"
+   or UNIVERSAL::isa $_[0], "Cpanel::JSON::XS::Boolean"
 }
 
 XSLoader::load 'Cpanel::JSON::XS', $VERSION;
 
-package Cpanel::JSON::XS::Boolean;
+package
+  JSON::XS::Boolean;
 
 use overload
    "0+"     => sub { ${$_[0]} },
